# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitorConfiguration(object):
    """
    Details of monitor configuration.
    """

    #: A constant which can be used with the config_type property of a MonitorConfiguration.
    #: This constant has a value of "BROWSER_CONFIG"
    CONFIG_TYPE_BROWSER_CONFIG = "BROWSER_CONFIG"

    #: A constant which can be used with the config_type property of a MonitorConfiguration.
    #: This constant has a value of "SCRIPTED_BROWSER_CONFIG"
    CONFIG_TYPE_SCRIPTED_BROWSER_CONFIG = "SCRIPTED_BROWSER_CONFIG"

    #: A constant which can be used with the config_type property of a MonitorConfiguration.
    #: This constant has a value of "REST_CONFIG"
    CONFIG_TYPE_REST_CONFIG = "REST_CONFIG"

    #: A constant which can be used with the config_type property of a MonitorConfiguration.
    #: This constant has a value of "SCRIPTED_REST_CONFIG"
    CONFIG_TYPE_SCRIPTED_REST_CONFIG = "SCRIPTED_REST_CONFIG"

    def __init__(self, **kwargs):
        """
        Initializes a new MonitorConfiguration object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.apm_synthetics.models.ScriptedRestMonitorConfiguration`
        * :class:`~oci.apm_synthetics.models.ScriptedBrowserMonitorConfiguration`
        * :class:`~oci.apm_synthetics.models.RestMonitorConfiguration`
        * :class:`~oci.apm_synthetics.models.BrowserMonitorConfiguration`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_type:
            The value to assign to the config_type property of this MonitorConfiguration.
            Allowed values for this property are: "BROWSER_CONFIG", "SCRIPTED_BROWSER_CONFIG", "REST_CONFIG", "SCRIPTED_REST_CONFIG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type config_type: str

        :param is_failure_retried:
            The value to assign to the is_failure_retried property of this MonitorConfiguration.
        :type is_failure_retried: bool

        """
        self.swagger_types = {
            'config_type': 'str',
            'is_failure_retried': 'bool'
        }

        self.attribute_map = {
            'config_type': 'configType',
            'is_failure_retried': 'isFailureRetried'
        }

        self._config_type = None
        self._is_failure_retried = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['configType']

        if type == 'SCRIPTED_REST_CONFIG':
            return 'ScriptedRestMonitorConfiguration'

        if type == 'SCRIPTED_BROWSER_CONFIG':
            return 'ScriptedBrowserMonitorConfiguration'

        if type == 'REST_CONFIG':
            return 'RestMonitorConfiguration'

        if type == 'BROWSER_CONFIG':
            return 'BrowserMonitorConfiguration'
        else:
            return 'MonitorConfiguration'

    @property
    def config_type(self):
        """
        Gets the config_type of this MonitorConfiguration.
        Type of configuration.

        Allowed values for this property are: "BROWSER_CONFIG", "SCRIPTED_BROWSER_CONFIG", "REST_CONFIG", "SCRIPTED_REST_CONFIG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The config_type of this MonitorConfiguration.
        :rtype: str
        """
        return self._config_type

    @config_type.setter
    def config_type(self, config_type):
        """
        Sets the config_type of this MonitorConfiguration.
        Type of configuration.


        :param config_type: The config_type of this MonitorConfiguration.
        :type: str
        """
        allowed_values = ["BROWSER_CONFIG", "SCRIPTED_BROWSER_CONFIG", "REST_CONFIG", "SCRIPTED_REST_CONFIG"]
        if not value_allowed_none_or_none_sentinel(config_type, allowed_values):
            config_type = 'UNKNOWN_ENUM_VALUE'
        self._config_type = config_type

    @property
    def is_failure_retried(self):
        """
        Gets the is_failure_retried of this MonitorConfiguration.
        If isFailureRetried is enabled, then a failed call will be retried.


        :return: The is_failure_retried of this MonitorConfiguration.
        :rtype: bool
        """
        return self._is_failure_retried

    @is_failure_retried.setter
    def is_failure_retried(self, is_failure_retried):
        """
        Sets the is_failure_retried of this MonitorConfiguration.
        If isFailureRetried is enabled, then a failed call will be retried.


        :param is_failure_retried: The is_failure_retried of this MonitorConfiguration.
        :type: bool
        """
        self._is_failure_retried = is_failure_retried

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .domain_client import DomainClient
from .domain_client_composite_operations import DomainClientCompositeOperations
from .domain_governance_client import DomainGovernanceClient
from .domain_governance_client_composite_operations import DomainGovernanceClientCompositeOperations
from .link_client import LinkClient
from .link_client_composite_operations import LinkClientCompositeOperations
from .orders_client import OrdersClient
from .orders_client_composite_operations import OrdersClientCompositeOperations
from .recipient_invitation_client import RecipientInvitationClient
from .recipient_invitation_client_composite_operations import RecipientInvitationClientCompositeOperations
from .sender_invitation_client import SenderInvitationClient
from .sender_invitation_client_composite_operations import SenderInvitationClientCompositeOperations
from .work_request_client import WorkRequestClient
from .work_request_client_composite_operations import WorkRequestClientCompositeOperations
from . import models

__all__ = ["DomainClient", "DomainClientCompositeOperations", "DomainGovernanceClient", "DomainGovernanceClientCompositeOperations", "LinkClient", "LinkClientCompositeOperations", "OrdersClient", "OrdersClientCompositeOperations", "RecipientInvitationClient", "RecipientInvitationClientCompositeOperations", "SenderInvitationClient", "SenderInvitationClientCompositeOperations", "WorkRequestClient", "WorkRequestClientCompositeOperations", "models"]



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Datafile(object):
    """
    The details of a datafile.
    """

    #: A constant which can be used with the status property of a Datafile.
    #: This constant has a value of "AVAILABLE"
    STATUS_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the status property of a Datafile.
    #: This constant has a value of "INVALID"
    STATUS_INVALID = "INVALID"

    #: A constant which can be used with the status property of a Datafile.
    #: This constant has a value of "OFFLINE"
    STATUS_OFFLINE = "OFFLINE"

    #: A constant which can be used with the status property of a Datafile.
    #: This constant has a value of "ONLINE"
    STATUS_ONLINE = "ONLINE"

    #: A constant which can be used with the status property of a Datafile.
    #: This constant has a value of "UNKNOWN"
    STATUS_UNKNOWN = "UNKNOWN"

    #: A constant which can be used with the online_status property of a Datafile.
    #: This constant has a value of "SYSOFF"
    ONLINE_STATUS_SYSOFF = "SYSOFF"

    #: A constant which can be used with the online_status property of a Datafile.
    #: This constant has a value of "SYSTEM"
    ONLINE_STATUS_SYSTEM = "SYSTEM"

    #: A constant which can be used with the online_status property of a Datafile.
    #: This constant has a value of "OFFLINE"
    ONLINE_STATUS_OFFLINE = "OFFLINE"

    #: A constant which can be used with the online_status property of a Datafile.
    #: This constant has a value of "ONLINE"
    ONLINE_STATUS_ONLINE = "ONLINE"

    #: A constant which can be used with the online_status property of a Datafile.
    #: This constant has a value of "RECOVER"
    ONLINE_STATUS_RECOVER = "RECOVER"

    #: A constant which can be used with the lost_write_protect property of a Datafile.
    #: This constant has a value of "ENABLED"
    LOST_WRITE_PROTECT_ENABLED = "ENABLED"

    #: A constant which can be used with the lost_write_protect property of a Datafile.
    #: This constant has a value of "PROTECT_OFF"
    LOST_WRITE_PROTECT_PROTECT_OFF = "PROTECT_OFF"

    #: A constant which can be used with the lost_write_protect property of a Datafile.
    #: This constant has a value of "SUSPEND"
    LOST_WRITE_PROTECT_SUSPEND = "SUSPEND"

    #: A constant which can be used with the shared property of a Datafile.
    #: This constant has a value of "SHARED"
    SHARED_SHARED = "SHARED"

    #: A constant which can be used with the shared property of a Datafile.
    #: This constant has a value of "LOCAL_FOR_RIM"
    SHARED_LOCAL_FOR_RIM = "LOCAL_FOR_RIM"

    #: A constant which can be used with the shared property of a Datafile.
    #: This constant has a value of "LOCAL_FOR_ALL"
    SHARED_LOCAL_FOR_ALL = "LOCAL_FOR_ALL"

    def __init__(self, **kwargs):
        """
        Initializes a new Datafile object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Datafile.
        :type name: str

        :param status:
            The value to assign to the status property of this Datafile.
            Allowed values for this property are: "AVAILABLE", "INVALID", "OFFLINE", "ONLINE", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param online_status:
            The value to assign to the online_status property of this Datafile.
            Allowed values for this property are: "SYSOFF", "SYSTEM", "OFFLINE", "ONLINE", "RECOVER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type online_status: str

        :param is_auto_extensible:
            The value to assign to the is_auto_extensible property of this Datafile.
        :type is_auto_extensible: bool

        :param lost_write_protect:
            The value to assign to the lost_write_protect property of this Datafile.
            Allowed values for this property are: "ENABLED", "PROTECT_OFF", "SUSPEND", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lost_write_protect: str

        :param shared:
            The value to assign to the shared property of this Datafile.
            Allowed values for this property are: "SHARED", "LOCAL_FOR_RIM", "LOCAL_FOR_ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type shared: str

        :param instance_id:
            The value to assign to the instance_id property of this Datafile.
        :type instance_id: float

        :param max_size_kb:
            The value to assign to the max_size_kb property of this Datafile.
        :type max_size_kb: float

        :param allocated_size_kb:
            The value to assign to the allocated_size_kb property of this Datafile.
        :type allocated_size_kb: float

        :param user_size_kb:
            The value to assign to the user_size_kb property of this Datafile.
        :type user_size_kb: float

        :param increment_by:
            The value to assign to the increment_by property of this Datafile.
        :type increment_by: float

        :param free_space_kb:
            The value to assign to the free_space_kb property of this Datafile.
        :type free_space_kb: float

        :param used_space_kb:
            The value to assign to the used_space_kb property of this Datafile.
        :type used_space_kb: float

        :param used_percent_available:
            The value to assign to the used_percent_available property of this Datafile.
        :type used_percent_available: float

        :param used_percent_allocated:
            The value to assign to the used_percent_allocated property of this Datafile.
        :type used_percent_allocated: float

        """
        self.swagger_types = {
            'name': 'str',
            'status': 'str',
            'online_status': 'str',
            'is_auto_extensible': 'bool',
            'lost_write_protect': 'str',
            'shared': 'str',
            'instance_id': 'float',
            'max_size_kb': 'float',
            'allocated_size_kb': 'float',
            'user_size_kb': 'float',
            'increment_by': 'float',
            'free_space_kb': 'float',
            'used_space_kb': 'float',
            'used_percent_available': 'float',
            'used_percent_allocated': 'float'
        }

        self.attribute_map = {
            'name': 'name',
            'status': 'status',
            'online_status': 'onlineStatus',
            'is_auto_extensible': 'isAutoExtensible',
            'lost_write_protect': 'lostWriteProtect',
            'shared': 'shared',
            'instance_id': 'instanceId',
            'max_size_kb': 'maxSizeKB',
            'allocated_size_kb': 'allocatedSizeKB',
            'user_size_kb': 'userSizeKB',
            'increment_by': 'incrementBy',
            'free_space_kb': 'freeSpaceKB',
            'used_space_kb': 'usedSpaceKB',
            'used_percent_available': 'usedPercentAvailable',
            'used_percent_allocated': 'usedPercentAllocated'
        }

        self._name = None
        self._status = None
        self._online_status = None
        self._is_auto_extensible = None
        self._lost_write_protect = None
        self._shared = None
        self._instance_id = None
        self._max_size_kb = None
        self._allocated_size_kb = None
        self._user_size_kb = None
        self._increment_by = None
        self._free_space_kb = None
        self._used_space_kb = None
        self._used_percent_available = None
        self._used_percent_allocated = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Datafile.
        The filename (including the path) of the datafile or tempfile.


        :return: The name of this Datafile.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Datafile.
        The filename (including the path) of the datafile or tempfile.


        :param name: The name of this Datafile.
        :type: str
        """
        self._name = name

    @property
    def status(self):
        """
        Gets the status of this Datafile.
        The status of the file. INVALID status is used when the file number is not in use, for example, a file in a tablespace that was dropped.

        Allowed values for this property are: "AVAILABLE", "INVALID", "OFFLINE", "ONLINE", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this Datafile.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Datafile.
        The status of the file. INVALID status is used when the file number is not in use, for example, a file in a tablespace that was dropped.


        :param status: The status of this Datafile.
        :type: str
        """
        allowed_values = ["AVAILABLE", "INVALID", "OFFLINE", "ONLINE", "UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def online_status(self):
        """
        Gets the online_status of this Datafile.
        The online status of the file.

        Allowed values for this property are: "SYSOFF", "SYSTEM", "OFFLINE", "ONLINE", "RECOVER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The online_status of this Datafile.
        :rtype: str
        """
        return self._online_status

    @online_status.setter
    def online_status(self, online_status):
        """
        Sets the online_status of this Datafile.
        The online status of the file.


        :param online_status: The online_status of this Datafile.
        :type: str
        """
        allowed_values = ["SYSOFF", "SYSTEM", "OFFLINE", "ONLINE", "RECOVER"]
        if not value_allowed_none_or_none_sentinel(online_status, allowed_values):
            online_status = 'UNKNOWN_ENUM_VALUE'
        self._online_status = online_status

    @property
    def is_auto_extensible(self):
        """
        Gets the is_auto_extensible of this Datafile.
        Indicates whether the datafile is auto-extensible.


        :return: The is_auto_extensible of this Datafile.
        :rtype: bool
        """
        return self._is_auto_extensible

    @is_auto_extensible.setter
    def is_auto_extensible(self, is_auto_extensible):
        """
        Sets the is_auto_extensible of this Datafile.
        Indicates whether the datafile is auto-extensible.


        :param is_auto_extensible: The is_auto_extensible of this Datafile.
        :type: bool
        """
        self._is_auto_extensible = is_auto_extensible

    @property
    def lost_write_protect(self):
        """
        Gets the lost_write_protect of this Datafile.
        The lost write protection status of the file.

        Allowed values for this property are: "ENABLED", "PROTECT_OFF", "SUSPEND", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lost_write_protect of this Datafile.
        :rtype: str
        """
        return self._lost_write_protect

    @lost_write_protect.setter
    def lost_write_protect(self, lost_write_protect):
        """
        Sets the lost_write_protect of this Datafile.
        The lost write protection status of the file.


        :param lost_write_protect: The lost_write_protect of this Datafile.
        :type: str
        """
        allowed_values = ["ENABLED", "PROTECT_OFF", "SUSPEND"]
        if not value_allowed_none_or_none_sentinel(lost_write_protect, allowed_values):
            lost_write_protect = 'UNKNOWN_ENUM_VALUE'
        self._lost_write_protect = lost_write_protect

    @property
    def shared(self):
        """
        Gets the shared of this Datafile.
        Type of tablespace this file belongs to. If it's for a shared tablespace, for a local temporary tablespace for RIM (read-only) instances, or for local temporary tablespace for all instance types.

        Allowed values for this property are: "SHARED", "LOCAL_FOR_RIM", "LOCAL_FOR_ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The shared of this Datafile.
        :rtype: str
        """
        return self._shared

    @shared.setter
    def shared(self, shared):
        """
        Sets the shared of this Datafile.
        Type of tablespace this file belongs to. If it's for a shared tablespace, for a local temporary tablespace for RIM (read-only) instances, or for local temporary tablespace for all instance types.


        :param shared: The shared of this Datafile.
        :type: str
        """
        allowed_values = ["SHARED", "LOCAL_FOR_RIM", "LOCAL_FOR_ALL"]
        if not value_allowed_none_or_none_sentinel(shared, allowed_values):
            shared = 'UNKNOWN_ENUM_VALUE'
        self._shared = shared

    @property
    def instance_id(self):
        """
        Gets the instance_id of this Datafile.
        Instance ID of the instance to which the temp file belongs. This column has a NULL value for temp files that belong to shared tablespaces.


        :return: The instance_id of this Datafile.
        :rtype: float
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this Datafile.
        Instance ID of the instance to which the temp file belongs. This column has a NULL value for temp files that belong to shared tablespaces.


        :param instance_id: The instance_id of this Datafile.
        :type: float
        """
        self._instance_id = instance_id

    @property
    def max_size_kb(self):
        """
        Gets the max_size_kb of this Datafile.
        The maximum file size in KB.


        :return: The max_size_kb of this Datafile.
        :rtype: float
        """
        return self._max_size_kb

    @max_size_kb.setter
    def max_size_kb(self, max_size_kb):
        """
        Sets the max_size_kb of this Datafile.
        The maximum file size in KB.


        :param max_size_kb: The max_size_kb of this Datafile.
        :type: float
        """
        self._max_size_kb = max_size_kb

    @property
    def allocated_size_kb(self):
        """
        Gets the allocated_size_kb of this Datafile.
        The allocated file size in KB.


        :return: The allocated_size_kb of this Datafile.
        :rtype: float
        """
        return self._allocated_size_kb

    @allocated_size_kb.setter
    def allocated_size_kb(self, allocated_size_kb):
        """
        Sets the allocated_size_kb of this Datafile.
        The allocated file size in KB.


        :param allocated_size_kb: The allocated_size_kb of this Datafile.
        :type: float
        """
        self._allocated_size_kb = allocated_size_kb

    @property
    def user_size_kb(self):
        """
        Gets the user_size_kb of this Datafile.
        The size of the file available for user data in KB. The actual size of the file minus the USER_BYTES value is used to store file-related metadata.


        :return: The user_size_kb of this Datafile.
        :rtype: float
        """
        return self._user_size_kb

    @user_size_kb.setter
    def user_size_kb(self, user_size_kb):
        """
        Sets the user_size_kb of this Datafile.
        The size of the file available for user data in KB. The actual size of the file minus the USER_BYTES value is used to store file-related metadata.


        :param user_size_kb: The user_size_kb of this Datafile.
        :type: float
        """
        self._user_size_kb = user_size_kb

    @property
    def increment_by(self):
        """
        Gets the increment_by of this Datafile.
        The number of blocks used as auto-extension increment.


        :return: The increment_by of this Datafile.
        :rtype: float
        """
        return self._increment_by

    @increment_by.setter
    def increment_by(self, increment_by):
        """
        Sets the increment_by of this Datafile.
        The number of blocks used as auto-extension increment.


        :param increment_by: The increment_by of this Datafile.
        :type: float
        """
        self._increment_by = increment_by

    @property
    def free_space_kb(self):
        """
        Gets the free_space_kb of this Datafile.
        The free space available in the datafile in KB.


        :return: The free_space_kb of this Datafile.
        :rtype: float
        """
        return self._free_space_kb

    @free_space_kb.setter
    def free_space_kb(self, free_space_kb):
        """
        Sets the free_space_kb of this Datafile.
        The free space available in the datafile in KB.


        :param free_space_kb: The free_space_kb of this Datafile.
        :type: float
        """
        self._free_space_kb = free_space_kb

    @property
    def used_space_kb(self):
        """
        Gets the used_space_kb of this Datafile.
        The total space used in the datafile in KB.


        :return: The used_space_kb of this Datafile.
        :rtype: float
        """
        return self._used_space_kb

    @used_space_kb.setter
    def used_space_kb(self, used_space_kb):
        """
        Sets the used_space_kb of this Datafile.
        The total space used in the datafile in KB.


        :param used_space_kb: The used_space_kb of this Datafile.
        :type: float
        """
        self._used_space_kb = used_space_kb

    @property
    def used_percent_available(self):
        """
        Gets the used_percent_available of this Datafile.
        The percentage of used space out of the maximum available space in the file.


        :return: The used_percent_available of this Datafile.
        :rtype: float
        """
        return self._used_percent_available

    @used_percent_available.setter
    def used_percent_available(self, used_percent_available):
        """
        Sets the used_percent_available of this Datafile.
        The percentage of used space out of the maximum available space in the file.


        :param used_percent_available: The used_percent_available of this Datafile.
        :type: float
        """
        self._used_percent_available = used_percent_available

    @property
    def used_percent_allocated(self):
        """
        Gets the used_percent_allocated of this Datafile.
        The percentage of used space out of the total allocated space in the file.


        :return: The used_percent_allocated of this Datafile.
        :rtype: float
        """
        return self._used_percent_allocated

    @used_percent_allocated.setter
    def used_percent_allocated(self, used_percent_allocated):
        """
        Sets the used_percent_allocated of this Datafile.
        The percentage of used space out of the total allocated space in the file.


        :param used_percent_allocated: The used_percent_allocated of this Datafile.
        :type: float
        """
        self._used_percent_allocated = used_percent_allocated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionInfo(object):
    """
    A single subscription's details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param spm_subscription_id:
            The value to assign to the spm_subscription_id property of this SubscriptionInfo.
        :type spm_subscription_id: str

        :param service:
            The value to assign to the service property of this SubscriptionInfo.
        :type service: str

        :param start_date:
            The value to assign to the start_date property of this SubscriptionInfo.
        :type start_date: datetime

        :param end_date:
            The value to assign to the end_date property of this SubscriptionInfo.
        :type end_date: datetime

        :param skus:
            The value to assign to the skus property of this SubscriptionInfo.
        :type skus: list[oci.tenant_manager_control_plane.models.Sku]

        """
        self.swagger_types = {
            'spm_subscription_id': 'str',
            'service': 'str',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'skus': 'list[Sku]'
        }

        self.attribute_map = {
            'spm_subscription_id': 'spmSubscriptionId',
            'service': 'service',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'skus': 'skus'
        }

        self._spm_subscription_id = None
        self._service = None
        self._start_date = None
        self._end_date = None
        self._skus = None

    @property
    def spm_subscription_id(self):
        """
        **[Required]** Gets the spm_subscription_id of this SubscriptionInfo.
        Subscription id.


        :return: The spm_subscription_id of this SubscriptionInfo.
        :rtype: str
        """
        return self._spm_subscription_id

    @spm_subscription_id.setter
    def spm_subscription_id(self, spm_subscription_id):
        """
        Sets the spm_subscription_id of this SubscriptionInfo.
        Subscription id.


        :param spm_subscription_id: The spm_subscription_id of this SubscriptionInfo.
        :type: str
        """
        self._spm_subscription_id = spm_subscription_id

    @property
    def service(self):
        """
        **[Required]** Gets the service of this SubscriptionInfo.
        Service name for subscription


        :return: The service of this SubscriptionInfo.
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this SubscriptionInfo.
        Service name for subscription


        :param service: The service of this SubscriptionInfo.
        :type: str
        """
        self._service = service

    @property
    def start_date(self):
        """
        **[Required]** Gets the start_date of this SubscriptionInfo.
        Subscription start date. An RFC3339 formatted datetime string


        :return: The start_date of this SubscriptionInfo.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this SubscriptionInfo.
        Subscription start date. An RFC3339 formatted datetime string


        :param start_date: The start_date of this SubscriptionInfo.
        :type: datetime
        """
        self._start_date = start_date

    @property
    def end_date(self):
        """
        **[Required]** Gets the end_date of this SubscriptionInfo.
        Subscription end date. An RFC3339 formatted datetime string


        :return: The end_date of this SubscriptionInfo.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this SubscriptionInfo.
        Subscription end date. An RFC3339 formatted datetime string


        :param end_date: The end_date of this SubscriptionInfo.
        :type: datetime
        """
        self._end_date = end_date

    @property
    def skus(self):
        """
        **[Required]** Gets the skus of this SubscriptionInfo.
        List of SKUs the subscription contains


        :return: The skus of this SubscriptionInfo.
        :rtype: list[oci.tenant_manager_control_plane.models.Sku]
        """
        return self._skus

    @skus.setter
    def skus(self, skus):
        """
        Sets the skus of this SubscriptionInfo.
        List of SKUs the subscription contains


        :param skus: The skus of this SubscriptionInfo.
        :type: list[oci.tenant_manager_control_plane.models.Sku]
        """
        self._skus = skus

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CveDetails(object):
    """
    Details on a CVE
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CveDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cve_reference:
            The value to assign to the cve_reference property of this CveDetails.
        :type cve_reference: str

        :param title:
            The value to assign to the title property of this CveDetails.
        :type title: str

        :param description:
            The value to assign to the description property of this CveDetails.
        :type description: str

        :param related_cve_reference:
            The value to assign to the related_cve_reference property of this CveDetails.
        :type related_cve_reference: str

        :param cvss3:
            The value to assign to the cvss3 property of this CveDetails.
        :type cvss3: str

        :param time_published:
            The value to assign to the time_published property of this CveDetails.
        :type time_published: datetime

        :param time_updated:
            The value to assign to the time_updated property of this CveDetails.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'cve_reference': 'str',
            'title': 'str',
            'description': 'str',
            'related_cve_reference': 'str',
            'cvss3': 'str',
            'time_published': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'cve_reference': 'cveReference',
            'title': 'title',
            'description': 'description',
            'related_cve_reference': 'relatedCveReference',
            'cvss3': 'cvss3',
            'time_published': 'timePublished',
            'time_updated': 'timeUpdated'
        }

        self._cve_reference = None
        self._title = None
        self._description = None
        self._related_cve_reference = None
        self._cvss3 = None
        self._time_published = None
        self._time_updated = None

    @property
    def cve_reference(self):
        """
        **[Required]** Gets the cve_reference of this CveDetails.
        CVE ID


        :return: The cve_reference of this CveDetails.
        :rtype: str
        """
        return self._cve_reference

    @cve_reference.setter
    def cve_reference(self, cve_reference):
        """
        Sets the cve_reference of this CveDetails.
        CVE ID


        :param cve_reference: The cve_reference of this CveDetails.
        :type: str
        """
        self._cve_reference = cve_reference

    @property
    def title(self):
        """
        **[Required]** Gets the title of this CveDetails.
        Vulnerability title


        :return: The title of this CveDetails.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this CveDetails.
        Vulnerability title


        :param title: The title of this CveDetails.
        :type: str
        """
        self._title = title

    @property
    def description(self):
        """
        Gets the description of this CveDetails.
        CVE description


        :return: The description of this CveDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CveDetails.
        CVE description


        :param description: The description of this CveDetails.
        :type: str
        """
        self._description = description

    @property
    def related_cve_reference(self):
        """
        Gets the related_cve_reference of this CveDetails.
        ID of related CVE, if applicable


        :return: The related_cve_reference of this CveDetails.
        :rtype: str
        """
        return self._related_cve_reference

    @related_cve_reference.setter
    def related_cve_reference(self, related_cve_reference):
        """
        Sets the related_cve_reference of this CveDetails.
        ID of related CVE, if applicable


        :param related_cve_reference: The related_cve_reference of this CveDetails.
        :type: str
        """
        self._related_cve_reference = related_cve_reference

    @property
    def cvss3(self):
        """
        **[Required]** Gets the cvss3 of this CveDetails.
        CVSS 3 Score


        :return: The cvss3 of this CveDetails.
        :rtype: str
        """
        return self._cvss3

    @cvss3.setter
    def cvss3(self, cvss3):
        """
        Sets the cvss3 of this CveDetails.
        CVSS 3 Score


        :param cvss3: The cvss3 of this CveDetails.
        :type: str
        """
        self._cvss3 = cvss3

    @property
    def time_published(self):
        """
        **[Required]** Gets the time_published of this CveDetails.
        Date/time the CVE was published


        :return: The time_published of this CveDetails.
        :rtype: datetime
        """
        return self._time_published

    @time_published.setter
    def time_published(self, time_published):
        """
        Sets the time_published of this CveDetails.
        Date/time the CVE was published


        :param time_published: The time_published of this CveDetails.
        :type: datetime
        """
        self._time_published = time_published

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this CveDetails.
        Date/time the CVE was last modified


        :return: The time_updated of this CveDetails.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this CveDetails.
        Date/time the CVE was last modified


        :param time_updated: The time_updated of this CveDetails.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
